let axios = require("axios");
/**
 * 发送 axios get请求
 *
 * @param {*} url
 * @param {*} [header={}]
 * @return {*} 
 */
function axiosGet(url, header = {}) {
  return axios.get(url, { headers: header }).then(
    d => d.data,
    err => {
      console.log(err.response);
      return err.response.data;
    }
  );
}

/**
 * 使用json格式发送post请求
 * 【使用方法】 axiosPostJson("http://cdn:8888/xxx", { c: 10, o: 9 });
 * @param {*} url
 * @param {*} json
 * @param {*} [header={}]
 * @return {*}
 */
function axiosPostJson(url, json, header = {}) {
  return axios
    .post(url, json, {
      headers: {
        ...header,
        "Content-Type": "application/json",
      },
    })
    .then(
      d => d.data,
      err => {
        console.log(err.response);
        return err.response.data;
      }
    );
}

/**
 * 使用a=1&b=2格式发送post请求
 * 【使用方法】 axiosPostParam("http://cdn:8888/xxx", { a: 1, c: 3 });
 * @param {*} url
 * @param {*} data
 * @param {*} header
 * @return {*}
 */
function axiosPostParam(url, data, header = {}) {
  return axios({
    method: "post",
    url,
    data,
    transformRequest: [
      function (data) {
        let ret = "";
        for (let it in data) {
          ret += encodeURIComponent(it) + "=" + encodeURIComponent(data[it]) + "&";
        }
        ret = ret.substring(0, ret.lastIndexOf("&"));
        return ret;
      },
    ],
    headers: {
      ...header,
      "Content-Type": "application/x-www-form-urlencoded",
    },
  }).then(
    d => d.data,
    err => {
      console.log(err.response);
      return err.response.data;
    }
  );
}

// 用法：

module.exports = {
  axiosGet,
  axiosPostJson,
  axiosPostParam,
};
