let path = require('path');
let fs = require('fs');
var cheerio = require('cheerio');

/**
 * 暂停${time} ms
 * @param {*} time 暂停时长
 * @param {boolean} [isWarn=false] 是否进行console提示
 * @return {*}
 */
function sleep(time, isWarn = false) {
  isWarn && console.log(`休息 ${time / 1000} s...`);
  return new Promise(resolve => setTimeout(resolve, time));
}

/**
 * 获取某个字符出现的次数
 * getCharCount('asdsad()()()()', '\\(')
 * @param {*} str
 * @param {*} char
 * @return {*}
 */
function getCharCount(str, char) {
  var regex = new RegExp(char, 'g'); // 使用g表示整个字符串都要匹配
  var result = str.match(regex); //match方法可在字符串内检索指定的值，或找到一个或多个正则表达式的匹配。
  var count = !result ? 0 : result.length;
  return count;
}

/**
 * 百分比转化为小数
 * @param {*} percent
 * @return {*}
 */
function toPoint(percent) {
  var str = percent.replace('%', '');
  str = str / 100;
  return str.toFixed(5);
}

/**
 * 替换某个字符串为另外一个字符串函数
 *
 * @param {any} bigStr  全部字符
 * @param {any} str1 被替换的字符
 * @param {any} str2 新字符
 * @returns 新的字符串
 */
function replaceAll(bigStr, str1, str2) {
  //把bigStr中的所有str1替换为str2
  var reg = new RegExp(str1, 'gm');
  return bigStr.replace(reg, str2);
}

/**
 * 写入文件【转换绝对路径要使用如下方法 path.resolve(__dirname, './xxx/yy')】
 * @param {*} filePath
 * @param {*} str
 * @return {*}
 */
function writeFile(filePath, str) {
  return new Promise(function (resolve, reject) {
    fs.writeFile(filePath, str, err => {
      if (err) {
        reject(err);
      } else {
        resolve();
      }
    });
  });
}

/**
 * html内容转换为jquery格式化
 * @param {*} htmlStr
 * @return {*} 
 */
function getParseHtml(htmlStr){
  return cheerio.load(htmlStr);
}

module.exports = {
  sleep,
  getCharCount,
  toPoint,
  replaceAll,
  writeFile,
  getParseHtml
};
